@@ -1209,9 +1209,10 @@ sub pod2html {
 
     delete $this->{UPARROW};
     delete $this->{UPARROW_FILE};
-    push @html, qq{<div id="header"><div id="header_top"><div><div>$NL};
-    push @html, qq{<img src="help:/kdoctools5-common/part_of_the_kde_family_horizontal_190.png" alt="Part of the KDE family"> $title - KDE Perldoc Viewer</div></div></div></div>};
-    push @html, q{<div class="pod">};
+    push @html, q{<div id="content">};
+    push @html, qq{<div id="header"><div id="header_content"><div id="header_left"><div id="header_right">$NL};
+    push @html, qq{<img src="help:/kdoctools6-common/top-kde.jpg" alt="KDE"> $title - KDE Perldoc Viewer</div></div></div></div>};
+    push @html, q{<div id="contentBody">};
 
     if ( exists $args{top} ) {
         push @html, qq{$NL<a name='_top'></a>$NL};
@@ -1255,7 +1256,7 @@ sub pod2html {
 
     push @html, qq{$args{index}$NL};
     push @html, @{$output};                      # The pod converted to HTML
-    push @html, qq{</div><div id="footer"><div id="footer_text">Generated by kio_perldoc, version $kio_perldoc_version</div></div>};
+    push @html, qq{</div><div id="footer"><div id="footer_text">Generated by kio_perldoc, version $kio_perldoc_version</div></div></div>};
     push @html, qq{</body></html>$NL};
 
     delete $this->{TIEDOUTPUT};
@@ -1392,27 +1393,10 @@ sub _organize_body {
 ################
 
 sub _organize_css {
-    my $perldoc_css = $ENV{'KIO_PERLDOC_CSSLOCATION'};
-    chomp $perldoc_css;
-
     return <<"EOL";
-<link rel="stylesheet" href="help:/kdoctools5-common/kde-default.css" type="text/css">
-<link rel="stylesheet" href="file://$perldoc_css" type="text/css">
-<style>
-    #header_top {
-        background-image: url("help:/kdoctools5-common/top.jpg");
-    }
-    #header_top div {
-        background-image: url("help:/kdoctools5-common/top-left.jpg");
-    }
-    #header_top div div {
-        background-image: url("help:/kdoctools5-common/top-right.jpg");
-    }
-    div.pod {
-        margin-left: 5em;
-        margin-right: 5em;
-    }
-</style>
+<link rel="stylesheet" href="help:/kdoctools6-common/kde-default.css" type="text/css">
+<link rel="stylesheet" href="help:/kdoctools6-common/kde-docs.css" type="text/css">
+<link rel="stylesheet" href="help:/kdoctools6-common/kde-localised.css" type="text/css">
 EOL
 }
 
